Trait ockam_core::env::FromString
source · pub trait FromString: Sized {
// Required method
fn from_string(s: &str) -> Result<Self>;
}Expand description
For-internal-use trait for types that can be parsed from string
Required Methods
sourcefn from_string(s: &str) -> Result<Self>
fn from_string(s: &str) -> Result<Self>
Parses string and gives the result. Can return an error in case of parsing error.
Object Safety
This trait is not object safe.